Package 'GLMBasedRaschEstimation'

Title: What the Package Does (One Line, Title Case)
Description: What the package does (one paragraph).
Authors: Ahmed Samir Megahed [aut, cre], Mustafa Ali Khalaf [aut], Ibraheem Mohamed Mougy [aut]
Maintainer: Ahmed Samir Megahed <[email protected]>
License: MIT + file LICENSE
Version: 0.0.0.9000
Built: 2026-05-20 10:49:34 UTC
Source: https://github.com/drahmedsamir/glmbasedraschestimation

Help Index


Compute Modified Item Response Probabilities

Description

Compute Modified Item Response Probabilities

Usage

compute_Modified_probabilities(results, theta_all)

Arguments

results

The data frame returned by fit_binary_irt.

theta_all

A numeric vector representing ability levels (total scores).

Value

A matrix of predicted probabilities.


Extract Rasch Item Difficulties in Original Order

Description

Extract Rasch Item Difficulties in Original Order

Usage

extract_rasch_difficulties_ordered(final_logit_matrix)

Arguments

final_logit_matrix

The matrix returned by rasch_logit.

Value

A data frame of item difficulties.


Fit Binary IRT Model using GLM

Description

Fit Binary IRT Model using GLM

Usage

fit_binary_irt(data_mat, total_score)

Arguments

data_mat

A numeric matrix of responses.

total_score

A numeric vector of total scores.

Value

A data frame containing Intercept, Slope, and Threshold for each item.


Plot Item Characteristic Curves (ICC)

Description

Plot Item Characteristic Curves (ICC)

Usage

plot_item_curves(theta_all, Modified_prob_matrix, results)

Arguments

theta_all

A numeric vector of ability levels.

Modified_prob_matrix

The matrix returned by compute_Modified_probabilities.

results

The data frame returned by fit_binary_irt.


Plot Rasch Item Curves

Description

Plot Rasch Item Curves

Usage

plot_rasch_curves(prob_matrix, final_logit_matrix)

Arguments

prob_matrix

The matrix returned by compute_Modified_probabilities.

final_logit_matrix

The matrix returned by rasch_logit.


Prepare Data for IRT Analysis

Description

Prepare Data for IRT Analysis

Usage

prepare_data(data)

Arguments

data

A data frame or matrix of binary responses (0 and 1).

Value

A list containing the numeric matrix and the calculated total scores.


Compute Logit and Row Means

Description

Compute Logit and Row Means

Usage

rasch_logit(prob_matrix)

Arguments

prob_matrix

The matrix returned by compute_Modified_probabilities.

Value

A matrix of logits with an added column for row means (Student Ability).