| Title: | What the Package Does (One Line, Title Case) |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | Ahmed Samir Megahed [aut, cre], Mustafa Ali Khalaf [aut], Ibraheem Mohamed Mougy [aut] |
| Maintainer: | Ahmed Samir Megahed <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-20 10:49:34 UTC |
| Source: | https://github.com/drahmedsamir/glmbasedraschestimation |
Compute Modified Item Response Probabilities
compute_Modified_probabilities(results, theta_all)compute_Modified_probabilities(results, theta_all)
results |
The data frame returned by fit_binary_irt. |
theta_all |
A numeric vector representing ability levels (total scores). |
A matrix of predicted probabilities.
Extract Rasch Item Difficulties in Original Order
extract_rasch_difficulties_ordered(final_logit_matrix)extract_rasch_difficulties_ordered(final_logit_matrix)
final_logit_matrix |
The matrix returned by rasch_logit. |
A data frame of item difficulties.
Fit Binary IRT Model using GLM
fit_binary_irt(data_mat, total_score)fit_binary_irt(data_mat, total_score)
data_mat |
A numeric matrix of responses. |
total_score |
A numeric vector of total scores. |
A data frame containing Intercept, Slope, and Threshold for each item.
Plot Item Characteristic Curves (ICC)
plot_item_curves(theta_all, Modified_prob_matrix, results)plot_item_curves(theta_all, Modified_prob_matrix, results)
theta_all |
A numeric vector of ability levels. |
Modified_prob_matrix |
The matrix returned by compute_Modified_probabilities. |
results |
The data frame returned by fit_binary_irt. |
Plot Rasch Item Curves
plot_rasch_curves(prob_matrix, final_logit_matrix)plot_rasch_curves(prob_matrix, final_logit_matrix)
prob_matrix |
The matrix returned by compute_Modified_probabilities. |
final_logit_matrix |
The matrix returned by rasch_logit. |
Prepare Data for IRT Analysis
prepare_data(data)prepare_data(data)
data |
A data frame or matrix of binary responses (0 and 1). |
A list containing the numeric matrix and the calculated total scores.
Compute Logit and Row Means
rasch_logit(prob_matrix)rasch_logit(prob_matrix)
prob_matrix |
The matrix returned by compute_Modified_probabilities. |
A matrix of logits with an added column for row means (Student Ability).